@@ -176,8 +176,8 @@ class GaussianProcess(WithParameters):
                 cached_data = self.cache['data'][cache_i]
 
                 data_size = min(cached_data.shape[0], data_x.shape[0])
-                cached_data_hash = hash(cached_data[:data_size, :].tostring())
-                data_x_hash = hash(data_x[:data_size, :].tostring())
+                cached_data_hash = hash(cached_data[:data_size, :].tobytes())
+                data_x_hash = hash(data_x[:data_size, :].tobytes())
 
                 size_diff = np.abs(cached_data.shape[0] - data_x.shape[0])
 
