@@ -20,7 +20,6 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.ticker import LinearLocator, FormatStrFormatter
-from mpl_toolkits.mplot3d import Axes3D
 
 plt.style.use('ggplot')
 
@@ -195,7 +194,7 @@ def gp_2d(gp, data=None, test_data=None, resolution=40, file_name=None):
 
     # Init plot
     fig = plt.figure()
-    axis = fig.gca(projection='3d')
+    axis = fig.add_subplot(projection='3d')
 
     # plot data
     if show_data is not None:
